@@ -1,7 +1,113 @@
+def insertStrForFilesName(directory,string,afterNumber):
+    import os
+    import re
+    if ((not isinstance(afterNumber, int)) or (afterNumber<-1)):
+            raise TypeError("afterNumber должно быть целое число не меньше -1")
+            return
+
+    files = os.listdir(directory)
+    if not files:
+        print("В папке нет файлов")
+        return 
+     
+    for ids,f in enumerate(files):
+        f_name, f_ext=os.path.splitext(f)
+        text=f_name
+        pattern=""
+        repl=str(string)
+        if afterNumber==0:
+            pattern=r"^"
+        elif afterNumber==-1 or afterNumber>len(f):
+            pattern=r"$"
+        else:
+            pat= '.'*int(afterNumber) 
+            pattern=re.match(pat,f_name).group(0)
+            repl=pattern+str(string)
+        m=re.sub(pattern, repl, text)
+        print(f"Old Name {text}")
+        print(f"New Name {m.strip()}")
+        new_name=m.strip()+f_ext
+        os.rename(directory+'/'+f, directory+'/'+new_name)
+
+def indexsForFilesWithRE(directory,count,symbols):
+    import os
+    import re
+    if ((not isinstance(count, int)) or (count<1)):
+            raise TypeError("count должно быть целое число не меньше 1")
+            return
+    files = os.listdir(directory)
+    if not files:
+        print("В папке нет файлов")
+        return 
+    for ids,f in enumerate(files):
+        f_name, f_ext=os.path.splitext(f)
+        text=f_name
+        pattern=r"^"
+        repl=str(ids+1).zfill(count)+symbols
+        m=re.sub(pattern, repl, text)
+        print(f"Old Name {text}")
+        print(f"New Name {m.strip()}")
+        new_name=m.strip()+f_ext
+        os.rename(directory+'/'+f, directory+'/'+new_name)
+
+def subForFilesWithRE(directory,pattern,repl):
+    import os
+    import re
+    files = os.listdir(directory)
+    if not files:
+        print("В папке нет файлов")
+        return 
+    for ids,f in enumerate(files):
+        f_name, f_ext=os.path.splitext(f)
+        text=f_name
+        m=re.sub(pattern, repl, text)
+        print(f"Old Name {text}")
+        print(f"New Name {m.strip()}")
+        new_name=m.strip()+f_ext
+        os.rename(directory+'/'+f, directory+'/'+new_name)
+
+def unionPdfsFiles(directory):
+    import os
+    from PyPDF2 import PdfFileReader, PdfFileMerger
+    pdfs = [f for f in os.listdir(directory) if f.endswith(".pdf")]
+    if not pdfs:
+        print("В папке нет pdf файлов")
+        return    
+    merger = PdfFileMerger()
+    for pdf in pdfs:
+        with open(directory+'/'+pdf, 'rb') as fd:
+            merger.append(PdfFileReader(fd))
+   
+    with open('unionPdfsFiles.pdf','wb') as fout:
+        merger.write(fout)
+    print("Сохранил файл unionPdfsFiles.pdf в основной директории")
+
+def namesFilesToExcel(directoryPdfs):
+  from PyPDF2 import PdfFileReader, PdfFileWriter
+  import os
+  import pandas as pd
+  import xlsxwriter
+  files = os.listdir(directoryPdfs)
+  lNames = [] 
+  lExt = []
+  for idx, f in enumerate(files):
+    f_name, f_ext = os.path.splitext(f)
+    lNames.append(f_name)
+    lExt.append(f)
+  dfToExcel = pd.DataFrame (lNames,columns = ['Names Files'])
+  dfToExcel['Full names'] = lExt
+  writer = pd.ExcelWriter("namesFiles" + ".xlsx", engine = 'xlsxwriter')
+  dfToExcel.to_excel(writer, startrow = 0, startcol = 0, index = False)
+  writer.save()
+  print("Сохранил файл namesFiles.xlsx в Основной директории")
+
 def docxToPdf(directory):
   from docx2pdf import convert
   import os
-  files = os.listdir(directory)
+  files = [f for f in os.listdir(directory) if f.endswith(".docx")]
+  if not files:
+    print("В папке нет docx файлов")
+    return    
   for ids,f in enumerate(files):
     f_name, f_ext = os.path.splitext(f)
     name = '{} {} {}'.format(ids+1,f_name, f_ext)
@@ -16,7 +122,7 @@ def check_tables(directory, numTable):
   files = os.listdir(directory)
   listSortedNatural = files
   document_out = Document() # новый документ с таблицами 0 всех файлов
-  text1 = 'таблицы {} из всех РПД'.format(numTable)
+  text1 = 'таблицы {} из всех docx файлов'.format(numTable)
   document_out.add_paragraph(text1)
   for ids, rpd in enumerate(listSortedNatural): 
     f_name, f_ext = os.path.splitext(rpd)
@@ -39,22 +145,6 @@ def check_tables(directory, numTable):
   document_out.save('all_tables.docx')
   print("создал файл all_tables.docx")
 
-def fromRupFullNames(fileRUP):
-  import pandas as pd
-  df_rup = pd.read_excel(fileRUP, sheet_name = 'Компетенции(2)', index_col = None, header = None )
-  df_rup = df_rup.dropna(subset = [4])
-  df_rup.drop(df_rup.head(2).index,inplace = True) # drop last n rows 
-  df_rup.drop(df_rup.tail(12).index,inplace = True) # drop last n rows 
-  df_rup.dropna(axis = 'columns',how = 'all', inplace = True)
-  df_rup.drop(df_rup.columns[[0,1, 3,5]], axis = 1, inplace = True)
-  df_rup.reset_index(drop = True, inplace = True)
-  df_rup = df_rup.rename(columns = {2: "Index", 4: "Name"})
-  writer = pd.ExcelWriter("rupFullNames" + ".xlsx", engine = 'xlsxwriter')
-  df_rup.to_excel(writer, sheet_name = 'FullName', startrow = 0, startcol = 0, index = False)
-  writer.save()
-  print("сохранил файл rupFullNames.xlsx на корневой директории py")
-
-
 def unionLeftRight(fileForUnion):
   import pandas as pd
   df_rup = pd.read_excel(fileForUnion, usecols = "A,B" )
@@ -86,11 +176,14 @@ def pagesFromPdfToExcel(directoryPdfs):
   from PyPDF2 import PdfFileReader, PdfFileWriter
   import os
   import pandas as pd
-  files = os.listdir(directoryPdfs)
-  listSortedNatural = files
+  import xlsxwriter
+  pdfs = [f for f in os.listdir(directoryPdfs) if f.endswith(".pdf")]
+  if not pdfs:
+    print("В папке нет pdf файлов")
+    return
   lNames = [] 
   lPages = []
-  for idx, f in enumerate(listSortedNatural):
+  for idx, f in enumerate(pdfs):
     pdf = PdfFileReader(directoryPdfs+"/"+f)
     page = pdf.numPages
     lPages.append(page)
@@ -104,17 +197,27 @@ def pagesFromPdfToExcel(directoryPdfs):
   writer.save()
   print("Сохранил файл pagesOfPdfFiles.xlsx на корневом каталоге py")
 
-def renameAllFiles(directory,inStrins,outString):
-  import os
-  files = os.listdir(directory)
-  for ids,f in enumerate(files):
-    f_name, f_ext = os.path.splitext(f)
-    print("Old Name {}".format(f_name))
-    f_name = f_name.replace(inStrins,outString)
-    print("New Name {}".format(f_name))
-    f_name = f_name.strip()
-    new_name = '{}{}'.format(f_name, f_ext)
-    os.rename(directory+'/'+f, directory+'/'+new_name)
+
+def renameAllFiles(directory,inStrins,outString,numStart,numEnd):
+    import os
+    files = os.listdir(directory)
+    if not files:
+        print("В папке нет файлов")
+
+    for ids,f in enumerate(files):
+        f_name, f_ext=os.path.splitext(f)
+        print("Old Name {}".format(f_name))
+        f_name=f_name.replace(inStrins,outString).strip()
+        f_start=f_name
+        if numStart>0:
+            f_start=f_name[:numStart]
+        f_end=""
+        if numEnd>0:
+            f_end=f_name[len(f_name)-numEnd:]
+        f_name=f_start+f_end
+        print("New Name {}".format(f_name))
+        new_name='{}{}'.format(f_name, f_ext)
+        os.rename(directory+'/'+f, directory+'/'+new_name)
 
 
 def indexForFiles(directory,constStr,startNum):
@@ -131,11 +234,14 @@ def indexForFiles(directory,constStr,startNum):
     
 def unionLeftRight(fileForUnion):
   import pandas as pd
-  df_rup = pd.read_excel(fileForUnion, usecols = "A,B" )
-  dfIn = pd.read_excel(fileForUnion)
+  import xlsxwriter
+  import xlrd
+  import openpyxl
+  df_rup = pd.read_excel(fileForUnion, usecols = "A,B", engine='openpyxl' )
+  dfIn = pd.read_excel(fileForUnion, engine='openpyxl')
   dfu = pd.DataFrame
   dfu = dfIn['Left']+" "+dfIn['Right']
   writer = pd.ExcelWriter("unionLeftRightOut" + ".xlsx", engine = 'xlsxwriter')
   dfu.to_excel(writer)
   writer.save()
-  print("Создал Файл unionLeftRightOut.xlsx в корневом каталоге Питон")
+  print("Создал Файл unionLeftRightOut.xlsx в корневом каталоге")
